@@ -151,8 +151,8 @@ proc filexfer::trigger {token} {
     set tail [file tail $downloadInfo($token-file)]
     regsub -all {\?\&\;} $tail "" tail  ;# get rid of confusing chars
 
-    set path [format "%s/filexfer/%s/download/%s?token=%s" \
-        $resources(huburl) $fxcookie $tail $token]
+    set path [format "/filexfer/%s/download/%s?token=%s" \
+        $fxcookie $tail $token]
     if {[catch {exec $clientaction url $path} result]} {
         filexfer::log "$clientaction url $path"
         filexfer::log "failed: $result"
